# Trajectory classes

```eval_rst
.. currentmodule:: baggianalysis.core

.. autosummary::
    :nosignatures:

    BaseTrajectory
   	FullTrajectory
    LazyTrajectory
    
.. autoclass:: BaseTrajectory
    
.. autoclass:: FullTrajectory

.. autoclass:: LazyTrajectory
```
